OcsInclusionProof

Struct OcsInclusionProof 

pub struct OcsInclusionProof {
    pub merkle_proof: MerkleProof,
    pub leaf_index: u64,
    pub tree_root: Digest,
}
Available on crate feature unstable only.
An OCS inclusion proof.

Proves that a specific ObjectReference appears at leaf_index in the modified-objects Merkle tree whose root is tree_root, and that tree_root is committed to by a CheckpointSummary’s CheckpointArtifacts commitment.

Fields

merkle_proof: MerkleProof

The Merkle inclusion proof for the leaf.

leaf_index: u64

The position of the leaf in the modified-objects tree.

tree_root: Digest

The 32-byte Merkle root of the modified-objects tree.

Implementations

Source

impl OcsInclusionProof

pub fn verify( &self, summary: &CheckpointSummary, object_ref: &ObjectReference, ) -> Result<(), ProofError>

Verify that object_ref was written in the checkpoint described by summary.

The caller is responsible for ensuring that summary itself is trusted (i.e. its BLS aggregate signature has been verified against the epoch’s validator committee). This method only checks that the proof and the summary are consistent.